      SUBROUTINE VCOPY(VECI, VECO, NVEC)
C
C***********************************************************************
C
C   NAME- VCOPY
C
C   LANGUAGE- FORTRAN 77    TYPE- SUBROUTINE        COMPUTER- CRAY    
C
C   VERSION- 1.0  DATE- 07/13/89  PROGRAMMER- S.SWEETLAND (SMSRC)
C   VERSION- 3.0  DATE- 05/10/96  PROGRAMMER- A.POZDNYAK (FDC)    
C     FOR REHOSTING TO THE CRAY, CHANGED ALL I*4 DECLARATIONS TO
C      INTEGER AND ALL R*4 DECLARATIONS TO REAL.
C
C   FUNCTION- COPIES ELEMENTS OF AN INPUT VECTOR (VECI)TO THE
C             CORRESPONDING ELEMENTS OF THE OUTPUT VECTOR (VECO).
C
C
C   CALLING SEQUENCE PARAMETERS-
C
C     NAME   TYPE  I/O    DESCRIPTION
C     ----   ----  ---    ------------
C     VECI   REAL  I      REAL VECTOR OF DIMENSION NVEC.
C
C     VECO   REAL  O      REAL VECTOR OF DIMENSION NVEC.
C
C     NVEC   INT   I      NUMBER OF ELEMENTS IN VECI/VECO.
C
C   LOCAL PARAMETERS-
C
C     NAME   TYPE  I/O    DESCRIPTION
C     ----   ----  ---    ------------
C     J      INT   N/A    DO LOOP INDEX.
C
C   EXIT STATES- NONE.
C
C***********************************************************************
C
      INTEGER  NVEC
      REAL     VECI(NVEC), VECO(NVEC)
C
      INTEGER  J
C
      INCLUDE 'SPVAL'
C
      DO 10 J = 1,NVEC
          VECO(J) = VECI(J)
   10 CONTINUE
C
      RETURN
      END
